Contains various lightweight utility functions, macros, and wrappers not found in the rust standard library.
Modules
- iter
- Contains extensions for rust iterators.
- prelude
- slice
- Contains extentions for rust slices.
- span
- Contains a thin
Copywrapper aroundRange<usize>. This has the same layout asRange<usize>. - str
- Contains extentions for rust
str.
Macros
- cstr
- Defines a
&'a static CStrfrom a byte string literal. This does not compile if an invalid CString is supplied.
Structs
- Dont
Drop - A wrapper that guarentees that the dropper of the underlying object cannot be safely called.
- Span
- A thin
Copywrapper aroundRange<usize>. This has the same layout asRange<usize>.
Functions
- transmute_
mut ⚠ - Transmutes between mutable references. This function is safer than casting between pointers because it keeps lifetimes intact. This may be useful when creating FFI wrappers.
- transmute_
ref ⚠ - Transmutes between references. This function is safer than casting between pointers because it keeps lifetimes intact. This may be useful when creating FFI wrappers.